@@ -11,9 +11,10 @@ static TYPE x UNUSED;
 #endif
 
 #ifdef SYMBOL
-static int exists UNUSED = !!SYMBOL;
+static int exists UNUSED = ! !SYMBOL;
 #endif
 
-int main(int argc UNUSED, char *argv[] UNUSED){
-	return 0;
+int main(int argc UNUSED, char *argv[]UNUSED)
+{
+  return 0;
 }
