@@ -24,7 +24,7 @@
   (See COPYING.txt)
 
   June 14, 2002 - May 15, 2007
-  $Id: cursor.c,v 1.5 2009/11/21 09:44:11 albert Exp $
+  $Id$
 */
 
 #include "cursor.h"
@@ -42,13 +42,18 @@ int hide_cursor = 1;
 int hide_cursor;
 #endif
 
-#if defined(NOKIA_770) || defined(__BEOS__)
+#if defined(NOKIA_770) || defined(__BEOS__) || defined(__HAIKU__)
 // Fancy cursors on BeOS are buggy in SDL
 int no_fancy_cursors = 1;
 #else
 int no_fancy_cursors;
 #endif
 
+/**
+ * Set the current cursor shape.
+ *
+ * @param c The cursor shape to use.
+ */
 void do_setcursor(SDL_Cursor * c)
 {
   /* Shut GCC up over the fact that the XBMs are #included within cursor.h
@@ -81,11 +86,16 @@ void do_setcursor(SDL_Cursor * c)
     SDL_SetCursor(c);
 }
 
+/**
+ * Free (deallocate) a cursor.
+ *
+ * @param cursor Pointer to a cursor to free; will be set to point to NULL afterwards.
+ */
 void free_cursor(SDL_Cursor ** cursor)
 {
   if (*cursor)
-  {
-    SDL_FreeCursor(*cursor);
-    *cursor = NULL;
-  }
+    {
+      SDL_FreeCursor(*cursor);
+      *cursor = NULL;
+    }
 }
