@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  $Id: get_fname.c,v 1.5 2009/11/23 07:45:25 albert Exp $
+  $Id$
 */
 
 #include <stdio.h>
@@ -30,22 +30,22 @@
 #include "debug.h"
 #include "compiler.h"
 
-  /* DIR_SAVE: Where is the user's saved directory?
-     This is where their saved files are stored
-     and where the "current_id.txt" file is saved.
-     
-     Windows predefines "savedir" as:
-     "C:\Documents and Settings\%USERNAME%\Application Data\TuxPaint"
-     though it may get overridden with "--savedir" option
+/* DIR_SAVE: Where is the user's saved directory?
+   This is where their saved files are stored
+   and where the "current_id.txt" file is saved.
 
-     BeOS similarly predefines "savedir" as "./userdata"...
+   Windows predefines "savedir" as:
+   "C:\Documents and Settings\%USERNAME%\Application Data\TuxPaint"
+   though it may get overridden with "--savedir" option
 
-     Macintosh: It's under ~/Library/Application Support/TuxPaint
+   BeOS similarly predefines "savedir" as "./userdata"...
 
-     Linux & Unix: It's under ~/.tuxpaint
+   Macintosh: It's under ~/Library/Application Support/TuxPaint
 
-     DIR_DATA: Where is the user's data directory?
-     This is where local fonts, brushes and stamps can be found. */
+   Linux & Unix: It's under ~/.tuxpaint
+
+   DIR_DATA: Where is the user's data directory?
+   This is where local fonts, brushes and stamps can be found. */
 
 
 const char *savedir;
@@ -57,13 +57,21 @@ const char *datadir;
 //        for caller-provided space, and maybe callee strdup.
 //        That's at most 4 functions per Tux Paint thread.
 
+/**
+ * Construct a filepath, given a filename, and what kind of file
+ * (data file, or saved images?)
+ *
+ * @param name Filaneme
+ * @param kind What kind of file? (DIR_SAVE or DIR_DATA?)
+ * @return Full fillpath
+ */
 char *get_fname(const char *const name, int kind)
 {
   char f[512];
-  const char *restrict const dir = (kind==DIR_SAVE) ? savedir : datadir;
+  const char *restrict const dir = (kind == DIR_SAVE) ? savedir : datadir;
 
   // Some mkdir()'s don't like trailing slashes
-  snprintf(f, sizeof(f), "%s%c%s", dir, (*name)?'/':'\0', name);
+  snprintf(f, sizeof(f), "%s%c%s", dir, (*name) ? '/' : '\0', name);
 
   return strdup(f);
 }
