@@ -24,22 +24,30 @@
   (See COPYING.txt)
 
   June 14, 2002 - February 18, 2006
-  $Id: rgblinear.c,v 1.3 2006/08/27 21:00:55 wkendrick Exp $
+  $Id$
 */
 
 #include "rgblinear.h"
 #include "debug.h"
 
+/**
+ * Return sRGB mapping (0-255 byte) of a linear (0.0 to 1.0) value
+ * (see rgblinear.h)
+ *
+ * @param linear Linear (float) value
+ * @return sRGB (byte) value
+ */
 unsigned char linear_to_sRGB(float linear)
 {
   unsigned slot;
+
   slot = linear * 4096.0 + 0.5;
   if (slot > 4095)
-  {
-    if (linear > 0.5)
-      slot = 4095;
-    else
-      slot = 0;
-  }
+    {
+      if (linear > 0.5)
+        slot = 4095;
+      else
+        slot = 0;
+    }
   return linear_to_sRGB_table[slot];
 }
