@@ -25,7 +25,6 @@
 # 
 # Last modified 2006.Feb.17
 
-echo 'main(){}' > dummy.c
 gcc $1 dummy.c > /dev/null 2>&1 && echo $1
-rm -f dummy.c a.out
+rm -f a.out
 
