@@ -24,7 +24,7 @@
   http://www.tuxpaint.org/
 
   June 14, 2002 - October 9, 2009
-  $Id: tools.h,v 1.14 2010/04/25 20:30:47 perepujal Exp $
+  $Id$
 */
 
 
@@ -121,13 +121,16 @@ const char *const tool_tips[NUM_TOOLS] = {
   gettext_noop("Click to start drawing a line. Let go to complete it."),
 
   // Shape tool instructions
-  gettext_noop("Pick a shape. Click to pick the center, drag, then let go when it is the size you want. Move around to rotate it, and click to draw it."),
+  gettext_noop
+    ("Pick a shape. Click to pick the center, drag, then let go when it is the size you want. Move around to rotate it, and click to draw it."),
 
   // Text tool instructions
-  gettext_noop("Choose a style of text. Click on your drawing and you can start typing. Press [Enter] or [Tab] to complete the text."),
+  gettext_noop
+    ("Choose a style of text. Click on your drawing and you can start typing. Press [Enter] or [Tab] to complete the text."),
 
   // Label tool instructions
-  gettext_noop("Choose a style of text. Click on your drawing and you can start typing. Press [Enter] or [Tab] to complete the text. By using the selector button and clicking an exist label, you can move it, edit it and change its text style."),
+  gettext_noop
+    ("Choose a style of text. Click on your drawing and you can start typing. Press [Enter] or [Tab] to complete the text. By using the selector button and clicking an existing label, you can move it, edit it and change its text style."),
 
   // Reserved...
   " ",
@@ -176,22 +179,22 @@ const char *const tool_tips[NUM_TOOLS] = {
 /* Tool icon filenames: */
 
 const char *const tool_img_fnames[NUM_TOOLS] = {
-  "images/tools/brush.png",
-  "images/tools/stamp.png",
-  "images/tools/lines.png",
-  "images/tools/shapes.png",
-  "images/tools/text.png",
-  "images/tools/label.png",
-  "images/ui/dead40x40.png",
-  "images/tools/magic.png",
-  "images/tools/undo.png",
-  "images/tools/redo.png",
-  "images/tools/eraser.png",
-  "images/tools/new.png",
-  "images/tools/open.png",
-  "images/tools/save.png",
-  "images/tools/print.png",
-  "images/tools/quit.png"
+  DATA_PREFIX "images/tools/brush.png",
+  DATA_PREFIX "images/tools/stamp.png",
+  DATA_PREFIX "images/tools/lines.png",
+  DATA_PREFIX "images/tools/shapes.png",
+  DATA_PREFIX "images/tools/text.png",
+  DATA_PREFIX "images/tools/label.png",
+  DATA_PREFIX "images/ui/dead40x40.png",
+  DATA_PREFIX "images/tools/magic.png",
+  DATA_PREFIX "images/tools/undo.png",
+  DATA_PREFIX "images/tools/redo.png",
+  DATA_PREFIX "images/tools/eraser.png",
+  DATA_PREFIX "images/tools/new.png",
+  DATA_PREFIX "images/tools/open.png",
+  DATA_PREFIX "images/tools/save.png",
+  DATA_PREFIX "images/tools/print.png",
+  DATA_PREFIX "images/tools/quit.png"
 };
 
 
